package serializer

import (
	"github.com/fonchain_enterprise/fonchain-approval/api/approval"
	"github.com/fonchain_enterprise/fonchain-approval/pkg/e"
	"github.com/fonchain_enterprise/fonchain-approval/pkg/model"
)

//BuildType 处理单个detail返回
func BuildType(entity *model.ApprovalType) *approval.CreateTypeRequest {

	response := &approval.CreateTypeRequest{
		ID:       entity.ID,
		Domain:   entity.Domain,
		Remark:   entity.Remark,
		Title:    entity.Title,
		KeyWord:  entity.KeyWord,
		IsCustom: e.Is_IsCustom_Yes,
		KeyInfos: BuildKeyInfo(entity.KeyJson),
	}
	if entity.ApprovalTypeGroup != nil {
		response.GroupName = entity.ApprovalTypeGroup.Title
		response.GroupId = entity.ApprovalTypeGroup.ID
	}

	if model.IsSystemType(entity.KeyWord) == true {
		response.IsCustom = e.Is_IsCustom_No
	}

	return response
}

func BuildKeyInfo(infos model.KeyInfos) []*approval.KeyInfo {
	var keyInfos []*approval.KeyInfo

	for _, t := range infos {
		temp := &approval.KeyInfo{
			ApprovalKey:   t.ApprovalKey,
			ApprovalName:  t.ApprovalName,
			ApprovalType:  t.ApprovalType,
			ApprovalValue: t.ApprovalValue,
			ApprovalMark:  t.ApprovalMark,
		}
		keyInfos = append(keyInfos, temp)
	}

	return keyInfos
}

//BuildGroup 处理单个detail返回
func BuildGroup(entity *model.ApprovalTypeGroup) *approval.CreateTypeGroupRequest {

	response := &approval.CreateTypeGroupRequest{
		ID:     entity.ID,
		Domain: *entity.Domain,
		Title:  entity.Title,
	}
	response.List = BuildTypes(entity.ApprovalTypes)

	return response
}

func BuildTypes(entity []*model.ApprovalType) (details []*approval.CreateTypeRequest) {

	for _, temp := range entity {
		details = append(details, BuildType(temp))
	}

	return details
}

func BuildGroups(entity []*model.ApprovalTypeGroup) (details []*approval.CreateTypeGroupRequest) {

	for _, temp := range entity {
		details = append(details, BuildGroup(temp))
	}

	return details
}
